"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createExtrinsicEventHandler = void 0;
const handlers_interfaces_1 = require("./handlers.interfaces");
function createExtrinsicEventHandler(pallet, successEvent, cb) {
    return ({ events = [], status, txHash }) => {
        const hash = txHash.toHex();
        if (status.isReady) {
            cb({ status: handlers_interfaces_1.ExtrinsicStatus.Sent, txHash: hash });
        }
        if (status.isInBlock) {
            const block = status.asInBlock.toString();
            events.forEach(({ event: { data, method, section } }) => {
                if (section === pallet && method === successEvent) {
                    if (method === 'Attempted') {
                        const eventData = data.at(0);
                        if (eventData.isIncomplete) {
                            cb({
                                status: handlers_interfaces_1.ExtrinsicStatus.Failed,
                                blockHash: block,
                                txHash: hash,
                                message: eventData.asIncomplete.toHuman().join('; '),
                            });
                            return;
                        }
                    }
                    cb({
                        status: handlers_interfaces_1.ExtrinsicStatus.Success,
                        blockHash: block,
                        txHash: hash,
                    });
                }
                if (section === 'system' && method === 'ExtrinsicFailed') {
                    cb({
                        status: handlers_interfaces_1.ExtrinsicStatus.Failed,
                        blockHash: block,
                        txHash: hash,
                        message: data.join('; '),
                    });
                }
            });
        }
    };
}
exports.createExtrinsicEventHandler = createExtrinsicEventHandler;
//# sourceMappingURL=createExtrinsicEventHandler.js.map